@@ -17,10 +17,7 @@ sub new {
 
   $self->{dir} = App::Unliner::Util::get_temp_dir();
 
-  if ($ENV{UNLINER_DEBUG}) {
-    print STDERR "unliner: TMP: $self->{dir}\n";
-    print STDERR "unliner: TMP: Not cleaning up temp directory because UNLINER_DEBUG specified\n";
-  }
+  debug_log("TMP: Not cleaning up temp directory $self->{dir} because UNLINER_DEBUG >= 2") if $ENV{UNLINER_DEBUG} >= 2;
 
   my $prev_sigint = $SIG{INT};
 
@@ -100,12 +97,10 @@ sub run {
                                         def_name => $args{def_name},
                                         argv => $args{argv},
                                       )
+                                 ->optimise
                                  ->execute;
 
   return $self;
-
-  #my $compiled_def = $self->_compile_def($args{def_name}, $args{argv});
-  #$self->_interpreter($compiled_def);
 }
 
 
